==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/LoadBalancerSettingsFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class LoadBalancerSettingsFluentImpl<A extends LoadBalancerSettingsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements LoadBalancerSettingsFluent<A>{

    private VisitableBuilder<? extends me.snowdrop.istio.api.networking.v1alpha3.LoadBalancerSettings.LbPolicy,?> lbPolicy;

    public LoadBalancerSettingsFluentImpl(){
    }
    public LoadBalancerSettingsFluentImpl(LoadBalancerSettings instance){
            this.withLbPolicy(instance.getLbPolicy()); 
    }

    
/**
 * This method has been deprecated, please use method buildLbPolicy instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.LoadBalancerSettings.LbPolicy getLbPolicy(){
            return this.lbPolicy!=null?this.lbPolicy.build():null;
    }

    public me.snowdrop.istio.api.networking.v1alpha3.LoadBalancerSettings.LbPolicy buildLbPolicy(){
            return this.lbPolicy!=null?this.lbPolicy.build():null;
    }

    public A withLbPolicy(me.snowdrop.istio.api.networking.v1alpha3.LoadBalancerSettings.LbPolicy lbPolicy){
            if (lbPolicy instanceof SimpleLbPolicy){ this.lbPolicy= new SimpleLbPolicyBuilder((SimpleLbPolicy)lbPolicy); _visitables.add(this.lbPolicy);}
            return (A) this;
    }

    public Boolean hasLbPolicy(){
            return this.lbPolicy != null;
    }

    public A withSimpleLbPolicy(SimpleLbPolicy simpleLbPolicy){
            _visitables.remove(this.lbPolicy);
            if (simpleLbPolicy!=null){ this.lbPolicy= new SimpleLbPolicyBuilder(simpleLbPolicy); _visitables.add(this.lbPolicy);} return (A) this;
    }

    public LoadBalancerSettingsFluent.SimpleLbPolicyNested<A> withNewSimpleLbPolicy(){
            return new SimpleLbPolicyNestedImpl();
    }

    public LoadBalancerSettingsFluent.SimpleLbPolicyNested<A> withNewSimpleLbPolicyLike(SimpleLbPolicy item){
            return new SimpleLbPolicyNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LoadBalancerSettingsFluentImpl that = (LoadBalancerSettingsFluentImpl) o;
            if (lbPolicy != null ? !lbPolicy.equals(that.lbPolicy) :that.lbPolicy != null) return false;
            return true;
    }


    public class SimpleLbPolicyNestedImpl<N> extends SimpleLbPolicyFluentImpl<LoadBalancerSettingsFluent.SimpleLbPolicyNested<N>> implements LoadBalancerSettingsFluent.SimpleLbPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final SimpleLbPolicyBuilder builder;
    
            SimpleLbPolicyNestedImpl(SimpleLbPolicy item){
                    this.builder = new SimpleLbPolicyBuilder(this, item);
            }
            SimpleLbPolicyNestedImpl(){
                    this.builder = new SimpleLbPolicyBuilder(this);
            }
    
    public N and(){
            return (N) LoadBalancerSettingsFluentImpl.this.withSimpleLbPolicy(builder.build());
    }
    public N endSimpleLbPolicy(){
            return and();
    }

}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/LoadBalancerSettingsFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public class LoadBalancerSettingsFluentImpl<A extends LoadBalancerSettingsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements LoadBalancerSettingsFluent<A>{

    private VisitableBuilder<? extends LoadBalancerSettings.LbPolicy,?> lbPolicy;

    public LoadBalancerSettingsFluentImpl(){
    }
    public LoadBalancerSettingsFluentImpl(LoadBalancerSettings instance){
            this.withLbPolicy(instance.getLbPolicy()); 
    }

    
/**
 * This method has been deprecated, please use method buildLbPolicy instead.
 * @return The buildable object.
 */
@Deprecated public LoadBalancerSettings.LbPolicy getLbPolicy(){
            return this.lbPolicy!=null?this.lbPolicy.build():null;
    }

    public LoadBalancerSettings.LbPolicy buildLbPolicy(){
            return this.lbPolicy!=null?this.lbPolicy.build():null;
    }

    public A withLbPolicy(LoadBalancerSettings.LbPolicy lbPolicy){
            if (lbPolicy instanceof SimpleLbPolicy){ this.lbPolicy= new SimpleLbPolicyBuilder((SimpleLbPolicy)lbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);}
            return (A) this;
    }

    public Boolean hasLbPolicy(){
            return this.lbPolicy != null;
    }

    public A withSimpleLbPolicy(SimpleLbPolicy simpleLbPolicy){
            _visitables.get("lbPolicy").remove(this.lbPolicy);
            if (simpleLbPolicy!=null){ this.lbPolicy= new SimpleLbPolicyBuilder(simpleLbPolicy); _visitables.get("lbPolicy").add(this.lbPolicy);} return (A) this;
    }

    public LoadBalancerSettingsFluent.SimpleLbPolicyNested<A> withNewSimpleLbPolicy(){
            return new SimpleLbPolicyNestedImpl();
    }

    public LoadBalancerSettingsFluent.SimpleLbPolicyNested<A> withNewSimpleLbPolicyLike(SimpleLbPolicy item){
            return new SimpleLbPolicyNestedImpl(item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            LoadBalancerSettingsFluentImpl that = (LoadBalancerSettingsFluentImpl) o;
            if (lbPolicy != null ? !lbPolicy.equals(that.lbPolicy) :that.lbPolicy != null) return false;
            return true;
    }


    public class SimpleLbPolicyNestedImpl<N> extends SimpleLbPolicyFluentImpl<LoadBalancerSettingsFluent.SimpleLbPolicyNested<N>> implements LoadBalancerSettingsFluent.SimpleLbPolicyNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final SimpleLbPolicyBuilder builder;
    
            SimpleLbPolicyNestedImpl(SimpleLbPolicy item){
                    this.builder = new SimpleLbPolicyBuilder(this, item);
            }
            SimpleLbPolicyNestedImpl(){
                    this.builder = new SimpleLbPolicyBuilder(this);
            }
    
    public N and(){
            return (N) LoadBalancerSettingsFluentImpl.this.withSimpleLbPolicy(builder.build());
    }
    public N endSimpleLbPolicy(){
            return and();
    }

}


}
